@@ -1,7 +1,7 @@
 /*
 * This file is part of the PySide project.
 *
-* Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
+* Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
@@ -23,7 +23,7 @@
 #ifndef GLOBALRECEIVER_H
 #define GLOBALRECEIVER_H
 
-#include <Python.h>
+#include <sbkpython.h>
 #include <QObject>
 #include <QHash>
 #include <QSet>
