@@ -1,7 +1,7 @@
 /*
 * This file is part of the PySide project.
 *
-* Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
+* Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
@@ -61,13 +61,22 @@ namespace {
 #ifdef IS_PY3K
     static void destroyMetaObject(PyObject* obj)
     {
-        delete reinterpret_cast<PySide::DynamicQMetaObject*>(PyCapsule_GetPointer(obj, 0));
+        void* ptr = PyCapsule_GetPointer(obj, 0);
+        PySide::DynamicQMetaObject* meta = reinterpret_cast<PySide::DynamicQMetaObject*>(ptr);
+        SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(meta);
+        if (wrapper)
+            Shiboken::BindingManager::instance().releaseWrapper(wrapper);
+        delete meta;
     }
 
 #else
     static void destroyMetaObject(void* obj)
     {
-        delete reinterpret_cast<PySide::DynamicQMetaObject*>(obj);
+        PySide::DynamicQMetaObject* meta = reinterpret_cast<PySide::DynamicQMetaObject*>(obj);
+        SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(meta);
+        if (wrapper)
+            Shiboken::BindingManager::instance().releaseWrapper(wrapper);
+        delete meta;
     }
 #endif
 }
@@ -95,6 +104,11 @@ PyObjectWrapper::PyObjectWrapper(const PyObjectWrapper &other)
 
 PyObjectWrapper::~PyObjectWrapper()
 {
+    // Check that Python is still initialized as sometimes this is called by a static destructor
+    // after Python interpeter is shutdown.
+    if (!Py_IsInitialized())
+        return;
+
     Shiboken::GilState gil;
     Py_DECREF(m_me);
 }
